@@ -1,11 +1,13 @@
 import inspect
+import typing
+import enum
 from pydantic import BaseModel
 
 
 def make_hashable(thing: any):
-    # pre-transform Pydantic models
-    if inspect.isclass(thing) and issubclass(thing, BaseModel):
-        thing = thing.model_json_schema()
+    # enums
+    if isinstance(thing, enum.Enum):
+        return (thing.name, thing.value)
     # pre-transform Pydantic model instances
     if isinstance(thing, BaseModel):
         thing = thing.model_dump()
@@ -22,6 +24,12 @@ def make_hashable(thing: any):
     # scalar types
     if isinstance(thing, (int, float, str, type(None))):
         return thing
+    # classes
+    if inspect.isclass(thing) or isinstance(thing, type) or typing.get_origin(thing):
+        return thing
+    # forward refs
+    if isinstance(thing, typing.ForwardRef):
+        return thing.__forward_arg__
     # other
     raise ValueError(f"Cannot hash `{thing}`")
 
